.. toctree::
    :maxdepth: 2
    :caption: API Documentation

    api/dag_cbor
    api/dag_cbor.decoding
    api/dag_cbor.decoding.err
    api/dag_cbor.encoding
    api/dag_cbor.encoding.err
    api/dag_cbor.ipld
    api/dag_cbor.random
